using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.SqlServer.Dts.Runtime;

namespace CustomTask
{
  
    //Step 1: Inherit from Task


    [DtsTask
   (
    DisplayName = "MyTaskCS",
    IconResource = "MyTask.MyTaskIcon.ico",
    UITypeName = "CustomTask.MyTaskUI,MyTask,Version= 1.0.0.0,Culture = Neutral,PublicKeyToken = fb703606bedcebed"
    )]
    public sealed class MyTask : Task
    {
        private string fileName = "";
        private bool fileDeleted = false;

      
        //Step: 2: Override validation

        /// <summary>
        /// Called by the TaskHost object. Verifies that the LoopCount, InitialValue, and IncrementValues are set correctly.
        /// </summary>
        /// <param name="connections">The package's Connections collection.</param>
        /// <param name="variableDispenser">The System variables visible to the task.</param>
        /// <param name="componentEvents">Used to raise events during execution.</param>
        /// <param name="log">Used to write log entries.</param>
        /// <returns>Returns a value from the DTSExecResult enumeration indicating validation success or failure.</returns>
        public override DTSExecResult Validate(Connections connections,
           VariableDispenser variableDispenser, IDTSComponentEvents events,
           IDTSLogging log)
        {
            try
            {
                if (this.fileName == "")
                {
                    //   Raise an OnError event.
                    events.FireError(0, "MyTask", "The FileName property must be configured.", "", 0);
                    //   Fail validation.
                    return DTSExecResult.Failure;
                }
                //   Return success.
                return DTSExecResult.Success;
            }
            catch (System.Exception exception)
            {
                //   Capture exceptions, post an error, and fail validation.
                events.FireError(0, "MyTask", exception.Message, "", 0);
                return DTSExecResult.Failure;
            }
        }





        //Step: 3 Override execute

        /// <summary>
        /// Called by the TaskHost.
        /// </summary>
        /// <param name="connections">The package's Connections collection.</param>
        /// <param name="variableDispenser">The System variable visible to the task.</param>
        /// <param name="componentEvents">Used to raise events during execution.</param>
        /// <param name="log">Used to write log entries.</param>
        /// <param name="transaction">Used to enlist in transactions.</param>
        /// <returns>Returns a value from the DTSExecResult enumeration indicating execution success or failure.</returns>
        public override DTSExecResult Execute(Connections cons, VariableDispenser vars, IDTSComponentEvents events, IDTSLogging log, object txn)
        {
            try
            {
                if (this.fileName == "")
                {
                    events.FireWarning(0, "MyTask", "No file specified.", "", 0);
                    this.fileDeleted = false;
                }
                else
                {
                    if (System.IO.File.Exists(this.fileName))
                    {
                        System.IO.File.Delete(this.fileName);
                        this.fileDeleted = true;
                    }
                    else
                        this.fileDeleted = false;
                }
                return DTSExecResult.Success;
            }
            catch (System.Exception exception)
            {
                //   Capture the exception and post an error.
                events.FireError(0, "MyTask", exception.Message, "", 0);
                return DTSExecResult.Failure;
            }
        }

        public string FileName
        {
            get { return this.fileName; }
            set { this.fileName = value; }
        }
        public override object ExecutionValue
        {
            get { return this.fileDeleted; }
        }
    }
}

